ARTP 1020 - Drawing II - Modern Campus Catalog™
Description: Volunteer State Community College is a public two-year community college in Gallatin, Tenn., serving a twelve-county region including the counties of Clay, Davidson, Jackson, Macon, Overton, Pickett, Putnam, Robertson, Smith, Sumner, Trousdale and Wilson. The College is committed to the education of a non-racially identifiable student body. Volunteer State Community College is accredited by the Commission on Colleges of the Southern Association of Colleges and Schools (1866 Southern Lane, Decatur, Georgia 30033-4097, telephone 404 - 679-4501) to award the Associate Degree and holds membership in the American Association of Community and Junior Colleges, and the Southern Association of Junior Colleges and the Tennessee College Association.
Keywords: Volunteer State Community College, Volunteer State, Community College, TBR Institution, Tennessee College, Higher Education, College, College Catalog, College Catalogue, 2005-2006 College Catalog, Vol State, Sumner County, Wilson County, Davidson County, Robertson County, Macon County, Trousdale County, Jackson County, Clay County

| Volunteer State Community College
| May 24, 2024 |  |
2013-2014 VSCC Catalog |
Select a Catalog |
HELP 2013-2014 VSCC Catalog [ARCHIVED CATALOG] Print-Friendly Page (opens a new window) Facebook this Page (opens a new window) Tweet this Page (opens a new window) Add to Portfolio (opens a new window)
# ARTP 1020 - Drawing II This course emphasizes conceptual skills and contemporary approaches to media and subject, based on the fundamental aspects of drawing–line, tone, space, form, and composition.; Observational skill development is maintained.; Figure drawing may be introduced. [This course was previously ART 102.] PREREQUISITES: ARTP 1010 or permission of instructor. Hours: Six contact hours per week. Credits: (3) Click here for the Spring 2024 Class Schedule Click here for the Summer 2024 Class Schedule Click here for the Fall 2024 Class Schedule Back to Top | Print-Friendly Page (opens a new window) Facebook this Page (opens a new window) Tweet this Page (opens a new window) Add to Portfolio (opens a new window)